SimpleFetcher<T> typedef
Fetches one page of items.
An empty result indicates that no subsequent page is available unless the controller has a configured page size.
Implementation
typedef SimpleFetcher<T> = Future<List<T>> Function(int page);