InfiniteScrollSliverGrid<T> class
An infinite-loading sliver grid for use inside a custom scroll view.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- InfiniteScrollSliverGrid
Constructors
-
InfiniteScrollSliverGrid({required ScrollController scrollController, SimpleFetcher<
T> ? simpleFetcher, TupleFetcher<T> ? tupleFetcher, FullFetcher<T> ? fullFetcher, required ItemBuilder<T> itemBuilder, required SliverGridDelegate gridDelegate, WidgetBuilder? loadingBuilder, ErrorBuilder? errorBuilder, WidgetBuilder? emptyBuilder, WidgetBuilder? loadingMoreBuilder, InfiniteScrollConfig config = const InfiniteScrollConfig(), bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, Key? key}) -
Creates an infinite sliver grid backed by exactly one fetcher strategy.
const
Properties
- addAutomaticKeepAlives → bool
-
Whether children are automatically kept alive.
final
- addRepaintBoundaries → bool
-
Whether children are wrapped in repaint boundaries.
final
- addSemanticIndexes → bool
-
Whether semantic indexes are assigned automatically.
final
- config → InfiniteScrollConfig
-
Pagination and scrolling behavior.
final
- emptyBuilder → WidgetBuilder?
-
Overrides the empty-state presentation.
final
- errorBuilder → ErrorBuilder?
-
Overrides the error presentation.
final
- gridDelegate → SliverGridDelegate
-
Controls the layout of grid tiles.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
itemBuilder
→ ItemBuilder<
T> -
Builds each loaded item.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingBuilder → WidgetBuilder?
-
Overrides the initial loading presentation.
final
- loadingMoreBuilder → WidgetBuilder?
-
Overrides the indicator appended while loading another page.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController
-
Controller owned by the surrounding scroll view.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< InfiniteScrollSliverGrid< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited